==> vtigercrm-5.3.0p0.tgz: modules/Campaigns/language/pt_br.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header$
 * Description:  Defines the English language pack
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): Valmir Carlos Trindade/Translate to Brazilian Portuguese|30/12/2010|Curitiba/Paraná/Brasil.|www.ttcasolucoes.com.br
 ********************************************************************************/

$mod_strings = Array(
// Added in release 5.0
'LBL_CAMPAIGN_INFORMATION'=>'Informação da Campanha',
'LBL_CUSTOM_INFORMATION'=>'Informação Customizada',
'LBL_DESCRIPTION_INFORMATION'=>'Descrição da Informação',
'LBL_EXPECTATIONS_AND_ACTUALS'=>'Expectativas & Atualidades',
      
'Campaign Name'=>'Nome Campanha',
'Campaign Type'=>'Tipo Campanha',
'Campaign Status'=>'Status Campanha',
'Campaign ID'=>'ID Campanha',
'Expected Close Date'=>'Previsão Fechamento',
'Expected Revenue'=>'Previsão Receita',
'Budget Cost'=>'Custo Orçado',
'Actual Cost'=>'Custo Atual',
'Expected Response'=>'Expectativa Resposta',
'Assigned To'=>'Responsável',
'Num Sent'=>'No. Envio',
'Created Time'=>'Data Criação',
'Modified Time'=>'Data Modificação',
'Description'=>'Descrição',
'Product'=>'Produto',
'Target Audience'=>'Público Alvo',  //Contribuição de Maristela Trindade
'TargetSize'=>'Tamanho Alvo',
'Sponsor'=>'Patrocinador',
      
'Expected Sales Count'=>'Montante Esperado Vendas',
'Expected Response Count'=>'Quantidade Resposta Esperada',
'Expected ROI'=>'Expectativa ROI',
      
'Actual Sales Count'=>'Montante Vendas Atual',
'Actual Response Count'=>'Quantidade Resposta Atual',
'Actual ROI'=>'ROI Atual',
'Select One'=>'Selecione Um',
'LBL_LOAD_LIST'=>'Carregar Lista',
      
//Added for existing Picklist Entries
      
'Conference'=>'Conferência',
'Webinar'=>'Seminário via Web',
'Trade Show'=>'Feiras',
'Public Relations'=>'Relações Públicas',
'Partners'=>'Parceiros',
'Referral Program'=>'Programa Referência',
'Advertisement'=>'Propaganda',
'Banner Ads'=>'Banners',
'Direct Mail'=>'Mala Direta',
'Email'=>'Email',
'Telemarketing'=>'Telemarketing',
'Others'=>'Outros',

'Planning'=>'Planejamento',
'Active'=>'Ativa',
'Inactive'=>'Inativa',
'Complete'=>'Completa',
'Cancelled'=>'Cancelada',

'Excellent'=>'Excelente',
'Good'=>'Boa',
'Average'=>'Média',
'Poor'=>'Ruim',

//Module Sequence Numbering
'Campaign No'=>'No. Campanha',
// status fields 
'--None--'=>'--Nada--',
'Contacted - Successful' => 'Contactado - Sucesso',
'Contacted - Unsuccessful' => 'Contactado - Insucesso',
'Contacted - Never Contact Again' => 'Contactado - Nunca Contactar Novamente'
// END

);

?>

==> vtigercrm-5.4.0.tgz: modules/Campaigns/language/pt_br.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header$
 * Description:  Defines the English language pack for Campaign Module
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): Valmir Carlos Trindade/Translate to Brazilian Portuguese| 03/03/2012 |Curitiba/Paraná/Brasil.|www.ttcasolucoes.com.br
 ********************************************************************************/

$mod_strings = Array(
// Added in release 5.0
'LBL_CAMPAIGN_INFORMATION'=>'Informação da Campanha',
'LBL_CUSTOM_INFORMATION'=>'Informação Customizada',
'LBL_DESCRIPTION_INFORMATION'=>'Descrição da Informação',
'LBL_EXPECTATIONS_AND_ACTUALS'=>'Expectativas & Atualidades',
      
'Campaign Name'=>'Nome Campanha',
'Campaign Type'=>'Tipo Campanha',
'Campaign Status'=>'Status Campanha',
'Campaign ID'=>'ID Campanha',
'Expected Close Date'=>'Previsão Fechamento',
'Expected Revenue'=>'Previsão Receita',
'Budget Cost'=>'Custo Orçado',
'Actual Cost'=>'Custo Atual',
'Expected Response'=>'Expectativa Resposta',
'Assigned To'=>'Responsável',
'Num Sent'=>'No. Envio',
'Created Time'=>'Data Criação',
'Modified Time'=>'Data Modificação',
'Description'=>'Descrição',
'Product'=>'Produto',
'Target Audience'=>'Público Alvo',  //Contribuição de Maristela Trindade
'TargetSize'=>'Tamanho Alvo',
'Sponsor'=>'Patrocinador',
      
'Expected Sales Count'=>'Montante Esperado Vendas',
'Expected Response Count'=>'Quantidade Resposta Esperada',
'Expected ROI'=>'Expectativa ROI',
      
'Actual Sales Count'=>'Montante Vendas Atual',
'Actual Response Count'=>'Quantidade Resposta Atual',
'Actual ROI'=>'ROI Atual',
'Select One'=>'Selecione Um',
'LBL_LOAD_LIST'=>'Carregar Lista',
      
//Added for existing Picklist Entries
      
'Conference'=>'Conferência',
'Webinar'=>'Seminário via Web',
'Trade Show'=>'Feiras',
'Public Relations'=>'Relações Públicas',
'Partners'=>'Parceiros',
'Referral Program'=>'Programa Referência',
'Advertisement'=>'Propaganda',
'Banner Ads'=>'Banners',
'Direct Mail'=>'Mala Direta',
'Email'=>'Email',
'Telemarketing'=>'Telemarketing',
'Others'=>'Outros',

'Planning'=>'Planejamento',
'Active'=>'Ativa',
'Inactive'=>'Inativa',
'Complete'=>'Completa',
'Cancelled'=>'Cancelada',

'Excellent'=>'Excelente',
'Good'=>'Boa',
'Average'=>'Média',
'Poor'=>'Ruim',

//Module Sequence Numbering
'Campaign No'=>'No. Campanha',
// status fields 
'--None--'=>'--Nada--',
'Contacted - Successful' => 'Contactado - Sucesso',
'Contacted - Unsuccessful' => 'Contactado - Insucesso',
'Contacted - Never Contact Again' => 'Contactado - Nunca Contactar Novamente',
// END
'Campaigns ID' => 'ID Campanhas',
);

?>
